{
    "$graph": [
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#collate_unique_SSU_headers.cwl/hits"
                }
            ],
            "steps": [
                {
                    "run": "#extract_coord_lines.cwl",
                    "in": [
                        {
                            "source": "#collate_unique_SSU_headers.cwl/hits",
                            "id": "#collate_unique_SSU_headers.cwl/extract_coord_lines/summary"
                        }
                    ],
                    "scatter": "#collate_unique_SSU_headers.cwl/extract_coord_lines/summary",
                    "out": [
                        "#collate_unique_SSU_headers.cwl/extract_coord_lines/coord_lines"
                    ],
                    "id": "#collate_unique_SSU_headers.cwl/extract_coord_lines"
                },
                {
                    "run": {
                        "id": "#collate_unique_SSU_headers.cwl/extract_names/extract_names",
                        "class": "CommandLineTool",
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 1
                                },
                                "doc": "The required columns are as follows:\n(1) target name: The name of the target sequence or profile.\n",
                                "id": "#collate_unique_SSU_headers.cwl/extract_names/extract_names/coordinate_lines"
                            }
                        ],
                        "baseCommand": [
                            "awk",
                            "{print $1}"
                        ],
                        "stdout": "names",
                        "outputs": [
                            {
                                "type": "File",
                                "id": "#collate_unique_SSU_headers.cwl/extract_names/extract_names/names",
                                "outputBinding": {
                                    "glob": "names"
                                }
                            }
                        ]
                    },
                    "in": [
                        {
                            "source": "#collate_unique_SSU_headers.cwl/extract_coord_lines/coord_lines",
                            "id": "#collate_unique_SSU_headers.cwl/extract_names/coordinate_lines"
                        }
                    ],
                    "scatter": "#collate_unique_SSU_headers.cwl/extract_names/coordinate_lines",
                    "out": [
                        "#collate_unique_SSU_headers.cwl/extract_names/names"
                    ],
                    "id": "#collate_unique_SSU_headers.cwl/extract_names"
                },
                {
                    "run": {
                        "id": "#collate_unique_SSU_headers.cwl/sort_uniq_names/sort_uniq_names",
                        "class": "CommandLineTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "inputBinding": {
                                    "position": 1
                                },
                                "id": "#collate_unique_SSU_headers.cwl/sort_uniq_names/sort_uniq_names/names"
                            }
                        ],
                        "baseCommand": [
                            "sort",
                            "--unique"
                        ],
                        "stdout": "sorted_uniq_names",
                        "outputs": [
                            {
                                "type": "File",
                                "id": "#collate_unique_SSU_headers.cwl/sort_uniq_names/sort_uniq_names/sorted_uniq_names",
                                "outputBinding": {
                                    "glob": "sorted_uniq_names"
                                }
                            }
                        ]
                    },
                    "in": [
                        {
                            "source": "#collate_unique_SSU_headers.cwl/extract_names/names",
                            "id": "#collate_unique_SSU_headers.cwl/sort_uniq_names/names"
                        }
                    ],
                    "out": [
                        "#collate_unique_SSU_headers.cwl/sort_uniq_names/sorted_uniq_names"
                    ],
                    "id": "#collate_unique_SSU_headers.cwl/sort_uniq_names"
                }
            ],
            "id": "#collate_unique_SSU_headers.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#collate_unique_SSU_headers.cwl/sort_uniq_names/sorted_uniq_names",
                    "id": "#collate_unique_SSU_headers.cwl/unique_hits"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "index a sequence file for use by esl-sfetch",
            "doc": "https://github.com/EddyRivasLab/easel",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 10,
                        "valueFrom": "$(self.basename)"
                    },
                    "format": [
                        "http://edamontology.org/format_1929",
                        "http://edamontology.org/format_1927",
                        "http://edamontology.org/format_1936",
                        "http://edamontology.org/format_1961",
                        "http://edamontology.org/format_1963"
                    ],
                    "id": "#esl-sfetch-index.cwl/sequences"
                }
            ],
            "baseCommand": [],
            "arguments": [
                "cp",
                "$(inputs.sequences.path)",
                "$(runtime.outdir)",
                {
                    "valueFrom": ";",
                    "shellQuote": false
                },
                "esl-sfetch",
                "--index"
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "format": "$(inputs.sequences.format)",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.basename)"
                    },
                    "id": "#esl-sfetch-index.cwl/sequences_with_index"
                }
            ],
            "id": "#esl-sfetch-index.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "extract by names from an indexed sequence file",
            "doc": "https://github.com/EddyRivasLab/easel",
            "inputs": [
                {
                    "label": "sequence file indexed by esl-sfetch-index",
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "inputBinding": {
                        "prefix": "-f",
                        "position": 1
                    },
                    "format": [
                        "http://edamontology.org/format_1929",
                        "http://edamontology.org/format_1927",
                        "http://edamontology.org/format_1936",
                        "http://edamontology.org/format_1961",
                        "http://edamontology.org/format_1963"
                    ],
                    "id": "#esl-sfetch-manyseqs.cwl/indexed_sequences"
                },
                {
                    "type": "File",
                    "label": "sequence names to retrieve, one per line",
                    "streamable": true,
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#esl-sfetch-manyseqs.cwl/names"
                },
                {
                    "doc": "GDF format: <newname> <from> <to> <source seqname>\nspace/tabdelimited\n",
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "-C"
                    },
                    "id": "#esl-sfetch-manyseqs.cwl/names_contain_subseq_coords"
                }
            ],
            "baseCommand": [
                "esl-sfetch"
            ],
            "stdout": "sequences",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-sfetch-manyseqs.cwl/sequences",
                    "outputBinding": {
                        "glob": "sequences"
                    }
                }
            ],
            "id": "#esl-sfetch-manyseqs.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "streamable": true,
                    "id": "#extract_coord_lines.cwl/summary"
                }
            ],
            "baseCommand": [
                "grep",
                "-v",
                "^#"
            ],
            "successCodes": [
                0,
                1
            ],
            "stdout": "coord_lines",
            "outputs": [
                {
                    "type": "File",
                    "id": "#extract_coord_lines.cwl/coord_lines",
                    "outputBinding": {
                        "glob": "coord_lines"
                    }
                }
            ],
            "id": "#extract_coord_lines.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "search profile(s) against a sequence database",
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005305"
                            ],
                            "version": [
                                "3.1b2"
                            ],
                            "package": "hmmer"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "label": "report sequences <= this E-value threshold in output",
                    "inputBinding": {
                        "prefix": "-E"
                    },
                    "id": "#hmmsearch.cwl/e_threshold"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "format": "http://edamontology.org/format_1370",
                    "id": "#hmmsearch.cwl/hmm_profiles"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#hmmsearch.cwl/sequence_query"
                }
            ],
            "baseCommand": [
                "hmmsearch"
            ],
            "arguments": [
                "--domtblout",
                "per_domain_summary.txt",
                {
                    "valueFrom": "$(runtime.cores)",
                    "prefix": "--cpu"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "per_domain_summary.txt"
                    },
                    "id": "#hmmsearch.cwl/per_domain_summary"
                }
            ],
            "id": "#hmmsearch.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/16s_rRNA_hmmer_matches"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/23s_rRNA_hmmer_matches"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/5s_rRNA_hmmer_matches"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/sequences"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/tRNA_matches"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/unique_rRNA_hits"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/unique_tRNA_hits"
                }
            ],
            "baseCommand": [],
            "arguments": [
                "ln",
                "-s",
                "$(inputs.unique_rRNA_hits.path)",
                "nhmmer.txt",
                ";",
                "ln",
                "-s",
                "$(inputs.16s_rRNA_hmmer_matches.path)",
                "nhmmer.16s.txt",
                ";",
                "ln",
                "-s",
                "$(inputs.23s_rRNA_hmmer_matches.path)",
                "nhmmer.23s.txt",
                ";",
                "ln",
                "-s",
                "$(inputs.5s_rRNA_hmmer_matches.path)",
                "nhmmer.5s.txt",
                ";",
                "rnaMaskingStep.py",
                "--hmmer",
                "nhmmer.txt",
                "--nhmmer",
                "$(inputs.unique_tRNA_hits.path)",
                "--seq_id",
                "$(inputs.tRNA_matches.path)",
                "--input",
                "$(inputs.sequences.path)",
                "--output",
                "masked_sequences.fasta"
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "masked_sequences.fasta"
                    },
                    "id": "#mask_RNA.cwl/masked_sequences"
                }
            ],
            "id": "#mask_RNA.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "search profile(s) against a sequence database",
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005305"
                            ],
                            "version": [
                                "3.1b2"
                            ],
                            "package": "hmmer"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "label": "report sequences >= this bit score threshold in output",
                    "inputBinding": {
                        "prefix": "-T"
                    },
                    "id": "#nhmmer.cwl/bitscore_threshold"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "format": "http://edamontology.org/format_1370",
                    "id": "#nhmmer.cwl/query"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#nhmmer.cwl/sequences"
                }
            ],
            "baseCommand": [
                "nhmmer"
            ],
            "arguments": [
                "--tblout",
                "per_target_summary.txt",
                {
                    "valueFrom": "$(runtime.cores)",
                    "prefix": "--cpu"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "per_target_summary.txt"
                    },
                    "id": "#nhmmer.cwl/per_target_summary"
                }
            ],
            "id": "#nhmmer.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#rRNA_selection.cwl/indexed_sequences"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "label": "rRNA protein model to search with",
                    "id": "#rRNA_selection.cwl/model"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#rRNA_selection.cwl/hmmsearch/per_domain_summary",
                    "id": "#rRNA_selection.cwl/hmmer_search_results"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#rRNA_selection.cwl/fetch_aligned_sequences/sequences",
                    "id": "#rRNA_selection.cwl/matching_sequences"
                }
            ],
            "steps": [
                {
                    "run": "#extract_coord_lines.cwl",
                    "in": [
                        {
                            "source": "#rRNA_selection.cwl/hmmsearch/per_domain_summary",
                            "id": "#rRNA_selection.cwl/extract_coord_lines/summary"
                        }
                    ],
                    "out": [
                        "#rRNA_selection.cwl/extract_coord_lines/coord_lines"
                    ],
                    "id": "#rRNA_selection.cwl/extract_coord_lines"
                },
                {
                    "run": {
                        "id": "#rRNA_selection.cwl/extract_coordinates/extract_coordinates",
                        "class": "CommandLineTool",
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 1
                                },
                                "streamable": true,
                                "doc": "The required columns are as follows:\n(1) target name: The name of the target sequence or profile.\n(18) from (ali coord): The start of the MEA alignment of this\n     domain with respect to the sequence, numbered 1..L for a\n     sequence of L residues.\n(19) to (ali coord): The end of the MEA alignment of this domain\n     with respect to the sequence, numbered 1..L for a sequence of\n     L residues.\n",
                                "id": "#rRNA_selection.cwl/extract_coordinates/extract_coordinates/coordinate_lines"
                            }
                        ],
                        "baseCommand": [
                            "awk",
                            "{print $1, $18, $19, $1}"
                        ],
                        "stdout": "formatted_names_and_coords",
                        "outputs": [
                            {
                                "type": "File",
                                "id": "#rRNA_selection.cwl/extract_coordinates/extract_coordinates/formatted_names_and_coords",
                                "outputBinding": {
                                    "glob": "formatted_names_and_coords"
                                }
                            }
                        ]
                    },
                    "in": [
                        {
                            "source": "#rRNA_selection.cwl/extract_coord_lines/coord_lines",
                            "id": "#rRNA_selection.cwl/extract_coordinates/coordinate_lines"
                        }
                    ],
                    "out": [
                        "#rRNA_selection.cwl/extract_coordinates/formatted_names_and_coords"
                    ],
                    "id": "#rRNA_selection.cwl/extract_coordinates"
                },
                {
                    "run": "#esl-sfetch-manyseqs.cwl",
                    "in": [
                        {
                            "source": "#rRNA_selection.cwl/indexed_sequences",
                            "id": "#rRNA_selection.cwl/fetch_aligned_sequences/indexed_sequences"
                        },
                        {
                            "source": "#rRNA_selection.cwl/extract_coordinates/formatted_names_and_coords",
                            "id": "#rRNA_selection.cwl/fetch_aligned_sequences/names"
                        },
                        {
                            "default": true,
                            "id": "#rRNA_selection.cwl/fetch_aligned_sequences/names_contain_subseq_coords"
                        }
                    ],
                    "out": [
                        "#rRNA_selection.cwl/fetch_aligned_sequences/sequences"
                    ],
                    "id": "#rRNA_selection.cwl/fetch_aligned_sequences"
                },
                {
                    "run": "#hmmsearch.cwl",
                    "in": [
                        {
                            "default": "1.0E-5",
                            "id": "#rRNA_selection.cwl/hmmsearch/e_threshold"
                        },
                        {
                            "source": "#rRNA_selection.cwl/model",
                            "id": "#rRNA_selection.cwl/hmmsearch/hmm_profiles"
                        },
                        {
                            "source": "#rRNA_selection.cwl/indexed_sequences",
                            "id": "#rRNA_selection.cwl/hmmsearch/sequence_query"
                        }
                    ],
                    "out": [
                        "#rRNA_selection.cwl/hmmsearch/per_domain_summary"
                    ],
                    "id": "#rRNA_selection.cwl/hmmsearch"
                }
            ],
            "id": "#rRNA_selection.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#tRNA_selection.cwl/indexed_sequences"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "label": "tRNA model to search with",
                    "id": "#tRNA_selection.cwl/model"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#tRNA_selection.cwl/nhmmer/per_target_summary",
                    "id": "#tRNA_selection.cwl/hmmer_search_results"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#tRNA_selection.cwl/fetch_aligned_sequences/sequences",
                    "id": "#tRNA_selection.cwl/matching_sequences"
                }
            ],
            "steps": [
                {
                    "run": "#extract_coord_lines.cwl",
                    "in": [
                        {
                            "source": "#tRNA_selection.cwl/nhmmer/per_target_summary",
                            "id": "#tRNA_selection.cwl/extract_coord_lines/summary"
                        }
                    ],
                    "out": [
                        "#tRNA_selection.cwl/extract_coord_lines/coord_lines"
                    ],
                    "id": "#tRNA_selection.cwl/extract_coord_lines"
                },
                {
                    "run": {
                        "id": "#tRNA_selection.cwl/extract_coordinates/extract_coordinates",
                        "class": "CommandLineTool",
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 1
                                },
                                "streamable": true,
                                "doc": "The required columns are as follows:\n(1) target name: The name of the target sequence or profile.\n(7) alifrom: The position in the target sequence at which the hit\n             starts\n(8) ali to: The position in the target sequence at which the hit\n            ends.\n",
                                "id": "#tRNA_selection.cwl/extract_coordinates/extract_coordinates/coordinate_lines"
                            }
                        ],
                        "baseCommand": [
                            "awk",
                            "{print $1, $7, $8, $1}"
                        ],
                        "stdout": "formatted_names_and_coords",
                        "outputs": [
                            {
                                "type": "File",
                                "id": "#tRNA_selection.cwl/extract_coordinates/extract_coordinates/formatted_names_and_coords",
                                "outputBinding": {
                                    "glob": "formatted_names_and_coords"
                                }
                            }
                        ]
                    },
                    "in": [
                        {
                            "source": "#tRNA_selection.cwl/extract_coord_lines/coord_lines",
                            "id": "#tRNA_selection.cwl/extract_coordinates/coordinate_lines"
                        }
                    ],
                    "out": [
                        "#tRNA_selection.cwl/extract_coordinates/formatted_names_and_coords"
                    ],
                    "id": "#tRNA_selection.cwl/extract_coordinates"
                },
                {
                    "run": "#esl-sfetch-manyseqs.cwl",
                    "in": [
                        {
                            "source": "#tRNA_selection.cwl/indexed_sequences",
                            "id": "#tRNA_selection.cwl/fetch_aligned_sequences/indexed_sequences"
                        },
                        {
                            "source": "#tRNA_selection.cwl/extract_coordinates/formatted_names_and_coords",
                            "id": "#tRNA_selection.cwl/fetch_aligned_sequences/names"
                        },
                        {
                            "default": true,
                            "id": "#tRNA_selection.cwl/fetch_aligned_sequences/names_contain_subseq_coords"
                        }
                    ],
                    "out": [
                        "#tRNA_selection.cwl/fetch_aligned_sequences/sequences"
                    ],
                    "id": "#tRNA_selection.cwl/fetch_aligned_sequences"
                },
                {
                    "run": "#nhmmer.cwl",
                    "in": [
                        {
                            "default": 40,
                            "id": "#tRNA_selection.cwl/nhmmer/bitscore_threshold"
                        },
                        {
                            "source": "#tRNA_selection.cwl/model",
                            "id": "#tRNA_selection.cwl/nhmmer/query"
                        },
                        {
                            "source": "#tRNA_selection.cwl/indexed_sequences",
                            "id": "#tRNA_selection.cwl/nhmmer/sequences"
                        }
                    ],
                    "out": [
                        "#tRNA_selection.cwl/nhmmer/per_target_summary"
                    ],
                    "id": "#tRNA_selection.cwl/nhmmer"
                }
            ],
            "id": "#tRNA_selection.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "RNASelector as a CWL workflow",
            "doc": "https://doi.org/10.1007/s12275-011-1213-z",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "record",
                            "name": "#trimmomatic-sliding_window.yaml/slidingWindow",
                            "fields": [
                                {
                                    "name": "#trimmomatic-sliding_window.yaml/slidingWindow/windowSize",
                                    "type": "int"
                                },
                                {
                                    "name": "#trimmomatic-sliding_window.yaml/slidingWindow/requiredQuality",
                                    "type": "int"
                                }
                            ]
                        },
                        {
                            "type": "enum",
                            "name": "#trimmomatic-end_mode.yaml/end_mode",
                            "symbols": [
                                "#trimmomatic-end_mode.yaml/end_mode/SE",
                                "#trimmomatic-end_mode.yaml/end_mode/PE"
                            ]
                        },
                        {
                            "type": "enum",
                            "name": "#trimmomatic-phred.yaml/phred",
                            "symbols": [
                                "#trimmomatic-phred.yaml/phred/64",
                                "#trimmomatic-phred.yaml/phred/33"
                            ]
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#main/16S_model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#main/23S_model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#main/5S_model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#main/reads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#main/tRNA_model"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/find_16S_matches/matching_sequences",
                    "id": "#main/16S_matches"
                },
                {
                    "type": "File",
                    "outputSource": "#main/mask_rRNA_and_tRNA/masked_sequences",
                    "id": "#main/masked_sequences"
                }
            ],
            "steps": [
                {
                    "run": "#collate_unique_SSU_headers.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/find_16S_matches/hmmer_search_results",
                                "#main/find_23S_matches/hmmer_search_results",
                                "#main/find_5S_matches/hmmer_search_results"
                            ],
                            "id": "#main/collate_unique_rRNA_hmmer_hits/hits"
                        }
                    ],
                    "out": [
                        "#main/collate_unique_rRNA_hmmer_hits/unique_hits"
                    ],
                    "id": "#main/collate_unique_rRNA_hmmer_hits"
                },
                {
                    "run": "#collate_unique_SSU_headers.cwl",
                    "in": [
                        {
                            "source": "#main/find_tRNA_matches/hmmer_search_results",
                            "valueFrom": "${ return [ self ]; }",
                            "id": "#main/collate_unique_tRNA_hmmer_hits/hits"
                        }
                    ],
                    "out": [
                        "#main/collate_unique_tRNA_hmmer_hits/unique_hits"
                    ],
                    "id": "#main/collate_unique_tRNA_hmmer_hits"
                },
                {
                    "run": "#rRNA_selection.cwl",
                    "in": [
                        {
                            "source": "#main/index_reads/sequences_with_index",
                            "id": "#main/find_16S_matches/indexed_sequences"
                        },
                        {
                            "source": "#main/16S_model",
                            "id": "#main/find_16S_matches/model"
                        }
                    ],
                    "out": [
                        "#main/find_16S_matches/matching_sequences",
                        "#main/find_16S_matches/hmmer_search_results"
                    ],
                    "id": "#main/find_16S_matches"
                },
                {
                    "run": "#rRNA_selection.cwl",
                    "in": [
                        {
                            "source": "#main/index_reads/sequences_with_index",
                            "id": "#main/find_23S_matches/indexed_sequences"
                        },
                        {
                            "source": "#main/23S_model",
                            "id": "#main/find_23S_matches/model"
                        }
                    ],
                    "out": [
                        "#main/find_23S_matches/matching_sequences",
                        "#main/find_23S_matches/hmmer_search_results"
                    ],
                    "id": "#main/find_23S_matches"
                },
                {
                    "run": "#rRNA_selection.cwl",
                    "in": [
                        {
                            "source": "#main/index_reads/sequences_with_index",
                            "id": "#main/find_5S_matches/indexed_sequences"
                        },
                        {
                            "source": "#main/5S_model",
                            "id": "#main/find_5S_matches/model"
                        }
                    ],
                    "out": [
                        "#main/find_5S_matches/matching_sequences",
                        "#main/find_5S_matches/hmmer_search_results"
                    ],
                    "id": "#main/find_5S_matches"
                },
                {
                    "run": "#tRNA_selection.cwl",
                    "in": [
                        {
                            "source": "#main/index_reads/sequences_with_index",
                            "id": "#main/find_tRNA_matches/indexed_sequences"
                        },
                        {
                            "source": "#main/tRNA_model",
                            "id": "#main/find_tRNA_matches/model"
                        }
                    ],
                    "out": [
                        "#main/find_tRNA_matches/matching_sequences",
                        "#main/find_tRNA_matches/hmmer_search_results"
                    ],
                    "id": "#main/find_tRNA_matches"
                },
                {
                    "run": "#esl-sfetch-index.cwl",
                    "in": [
                        {
                            "source": "#main/reads",
                            "id": "#main/index_reads/sequences"
                        }
                    ],
                    "out": [
                        "#main/index_reads/sequences_with_index"
                    ],
                    "id": "#main/index_reads"
                },
                {
                    "run": "#mask_RNA.cwl",
                    "in": [
                        {
                            "source": "#main/find_16S_matches/hmmer_search_results",
                            "id": "#main/mask_rRNA_and_tRNA/16s_rRNA_hmmer_matches"
                        },
                        {
                            "source": "#main/find_23S_matches/hmmer_search_results",
                            "id": "#main/mask_rRNA_and_tRNA/23s_rRNA_hmmer_matches"
                        },
                        {
                            "source": "#main/find_5S_matches/hmmer_search_results",
                            "id": "#main/mask_rRNA_and_tRNA/5s_rRNA_hmmer_matches"
                        },
                        {
                            "source": "#main/index_reads/sequences_with_index",
                            "id": "#main/mask_rRNA_and_tRNA/sequences"
                        },
                        {
                            "source": "#main/find_tRNA_matches/hmmer_search_results",
                            "id": "#main/mask_rRNA_and_tRNA/tRNA_matches"
                        },
                        {
                            "source": "#main/collate_unique_rRNA_hmmer_hits/unique_hits",
                            "id": "#main/mask_rRNA_and_tRNA/unique_rRNA_hits"
                        },
                        {
                            "source": "#main/collate_unique_tRNA_hmmer_hits/unique_hits",
                            "id": "#main/mask_rRNA_and_tRNA/unique_tRNA_hits"
                        }
                    ],
                    "out": [
                        "#main/mask_rRNA_and_tRNA/masked_sequences"
                    ],
                    "id": "#main/mask_rRNA_and_tRNA"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/docs/schema_org_rdfa.html",
        "http://edamontology.org/EDAM_1.16.owl"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
